@@ -666,6 +666,7 @@ def compute_extensive_kpis(data_df = None, strat = None):
 
 
 def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='./', plot_html=False, write_file=True):
+    clean_title = title.replace(' ', '_').replace('.', '')
     if plot_html:
         fig = realtime_plotting_utility.plot_multiple_time_series(
             data_df=data,
@@ -737,7 +738,6 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
 
                 writer.save()
             if write_file:
-                clean_title = title.replace(' ', '_')
                 writer = pd.ExcelWriter(local_root_directory + f'perf_dd_{me_strat_name}_{clean_title}.xlsx',
                                         engine='xlsxwriter')
                 data.to_excel(writer, sheet_name='kpi')
@@ -810,7 +810,6 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 'epoch realized max drawdown'].round(decimals=2)
 
             if write_file:
-                clean_title = title.replace(' ','_')
                 writer = pd.ExcelWriter(local_root_directory + f'epoch_{me_strat_name}_{clean_title}.xlsx',
                                         engine='xlsxwriter')
                 epochkpis_df.to_excel(writer, sheet_name='kpis per epoch')
